#!/bin/bash
#set -x
# Records the CPU temp, called from "tempiconsvg" to display in system tray
# depends: +lm-sensors(optional), +tempiconsvg
# other unix: +gtkdialog >=0.8.0
ver=0.16

PREFIX=`dirname $0`
export PREFIX

PROG=`basename $0`

#check sensors installed
export SENSORS=`which sensors`

[ ! -d /tmp/tempicon ] && mkdir /tmp/tempicon

#usage
usagefunc(){
echo "This program is called from tempiconsvg binary."
echo "You can run it stand alone to setup modules for lm_sensors."
echo "	-h|-help -show this help and exit "
echo "	-v|-version -show the $PROG version and exit"
echo "	-s|-sensor-help -help with loading a module"
echo -e "	-m|-module <MODULE> where <MODULE> is the module needed for \n\"sensors\" to run \
for example: k10temp, k8temp. \nThis can be found by running \
\n\"sensors-detect\". \nOnce a module is chosen then the program needs to be restarted."
echo "If no MODULE is specified \"coretemp\" will be loaded"
echo "NOTE: Only one argument to $PROG will be allowed"
}

#help for sensors
sensorshelpfunc()
{
echo -e '<window title="sensor help">
 <vbox>
  <frame>
   <text><input file>'$PREFIX'/bin/tempicon.hlp</input></text>
  </frame>
  <hbox><button ok></button>
  </hbox>
 </vbox>
</window>' > /tmp/tempicon/help
gtkdialog -f /tmp/tempicon/help	
}

case "$1" in
-h|-*help)usagefunc && exit 
;;
-v|-*version)echo "${PROG}-${ver}" && exit 
;;
-s|-*sensor-help)sensorshelpfunc
exit 
;;
-m|-*module)MODULE="$2"
echo "MODULE="$MODULE" " > /etc/tempicon.conf
echo "$MODULE will be loaded next time $PROG starts"
exit ;;
*)echo ;;
esac

#get cpu temp

cputempfunc(){

	 FILE=`find /sys/devices/ -name temp1_input|head -n1`
	 OUT1=`cat $FILE`
	 if [ ! $OUT1 ];then
	    FILE=`find /sys/bus/acpi/devices/ -name temp|head -n1`
	    OUT1=`cat $FILE`
	 fi
	 if [ ! $OUT1 ];then echo "not working" && break #exit
	    else OUT=`echo ${OUT1%???}`
	 fi
	 echo ${OUT} > /tmp/tempicon/count
	 
}

#lm_sensors installed
if [ $SENSORS ];then
 #if existing read config
 if [ -f /etc/tempicon.conf ];then
  . /etc/tempicon.conf
  modprobe $MODULE
  [ $? -ne 0 ] && rm /etc/tempicon.conf && echo "Loading $MODULE failed, removing /etc/tempicon.conf"
 fi

 #check a module is loaded if not, try to load one
 lsmod|grep -q coretemp
 [ "$?" = "0" ] && CORETEMP=0 || CORETEMP=1
 lsmod|grep -q k*temp
 [ "$?" = "0" ] && KTEMP=0 || KTEMP=1
 if [[ "$CORETEMP" = "1" && "$KTEMP" = "1" ]];then
	for m in coretemp k8temp k10temp
	 do modprobe $m 2>/dev/null
		if [ "$?" = "0" ];then echo L=0 >/tmp/tempicon/module.state
			break 
		  else echo L=1 >/tmp/tempicon/module.state
		continue
		fi
	 done
	 . /tmp/tempicon/module.state
	[ "$L" = "1" ] && sensorshelpfunc && exit
 fi
fi


cputempfunc &

sleep 1
[ -f /tmp/tempicon/count ]&& VALUE=`cat /tmp/tempicon/count`
if [ ! $VALUE ];then 
  if [ $SENSORS ];then
   xmessage -c -bg pink "TEMPICON ERROR: Your module doesn't work. Run \"sensors-detect\". Removing from Startup"
   #chmod 644 $HOME/Startup/tempicon.sh
   rm -f $HOME/Startup/tempiconsvg && exit
   
    else
    xmessage -c -bg pink "TEMPICON ERROR: Your system isn't supported. Try installing lm_sensors. Removing from Startup"
    #chmod 644 $HOME/Startup/tempicon.sh
    rm -f $HOME/Startup/tempiconsvg 2>/dev/null && exit
  fi
fi
#all good, run
sleep 1
